Gamepad

LB |  |  | RB
LT |  |  | RT
↖️ | ⬆️ | ↗️ |  | Y |
⬅️ | 🔄 | ➡️ | X |  | B
↙️ | ⬇️ | ↘️ |  | A |

Please press any button on your gamepad.
Runtime: min
Show timer
Pick interval: s
Receiver No:
Action:
Power: %
Duration: ms
Reaction time: ms
Immune time: ms
Play buttons:
Hold buttons:

    0:↖️, 1:⬆️, 2:↗️,
    3:⬅️, 4:🔄, 5:➡️,
    6:↙️, 7:⬇️, 8:↘️,
    9:Y, 10:X, 11:B, 12:A,
    13:LB, 14:RB, 15:LT, 16:RT